Export Package VRC : bcB40Mc4cn24
Update compared VRC:   B40 c4cn24
Only Package       : Yes
Based on sessions  : No
Script sources     : No
Function  sources  : No
Library sources    : No
---------------------------------------
C = Charts
q = Questions
c = Messages
l = Labels
d = Domains
t = Table Definitions
s = Sessions
p = Scripts
o = Objects
f = Forms
F = Form Dumps
m = Menus
M = Menu Dumps
r = Reports
i = Impl. Functions
b = Functions
h = Help Text Codes
----------------------
pbccnvvtest                         B40Mc4cn24 (without source)
pbcgct0106                          B40Mc4cn24 (without source)
pbcgcthistory                       B40Mc4cn24 (without source)
pbcrunconvdll                       B40Mc4cn24 (without source)
pbcruninitrep                       B40Mc4cn24 (without source)
cbcbcgct0106.01                     B40Mc4cn24
obcgct0106                          B40Mc4cn24
obcgcthistory                       B40Mc4cn24
obcrunconvdll                       B40Mc4cn24
obcruninitrep                       B40Mc4cn24
obcsql3272                          B40Mc4cn24
